@@ -2,7 +2,7 @@ use crate::prelude::*;
 use crate::{enums::*, widget::Widget};
 use wasm_bindgen::JsValue;
 
-#[derive(Clone)]
+#[derive(Debug, Clone)]
 pub struct Link {
     inner: Widget,
 }
@@ -24,12 +24,7 @@ impl WidgetBase for Link {
         crate::group::Group::current_attach(&inner);
         Self { inner }
     }
-    fn default_fill() -> Self {
-        let s = Self::default();
-        s.inner.set_style(Style::Width, "100%");
-        s.inner.set_style(Style::Height, "100%");
-        s
-    }
+
     unsafe fn from_widget(widget: &Widget) -> Self {
         Self {
             inner: widget.clone(),
@@ -43,3 +38,26 @@ impl WidgetBase for Link {
 impl WidgetExt for Link {}
 
 impl GroupExt for Link {}
+
+#[derive(Debug, Clone)]
+pub struct Break {
+    inner: Widget,
+}
+
+impl WidgetBase for Break {
+    fn default() -> Self {
+        let inner = Widget::new(WidgetType::Br);
+        crate::group::Group::current_attach(&inner);
+        Self { inner }
+    }
+    unsafe fn from_widget(widget: &Widget) -> Self {
+        Self {
+            inner: widget.clone(),
+        }
+    }
+    fn inner(&self) -> Widget {
+        self.inner.clone()
+    }
+}
+
+impl WidgetExt for Break {}
