@@ -1,16 +1,17 @@
 use crate::enums::*;
 use crate::traits::WidgetExt;
 use wasm_bindgen::JsCast;
+use wasm_bindgen::UnwrapThrowExt;
 
 pub trait InputExt: WidgetExt {
     fn value(&self) -> String {
         let c = self.inner();
-        let elem: &web_sys::HtmlInputElement = c.dyn_ref().unwrap();
+        let elem: &web_sys::HtmlInputElement = c.dyn_ref().unwrap_throw();
         elem.clone().value()
     }
     fn set_value(&self, s: &str) {
         let c = self.inner();
-        let elem: &web_sys::HtmlInputElement = c.dyn_ref().unwrap();
+        let elem: &web_sys::HtmlInputElement = c.dyn_ref().unwrap_throw();
         elem.set_value(s);
     }
     /// Sets the widget's color
@@ -19,13 +20,13 @@ pub trait InputExt: WidgetExt {
     }
     /// Returns the widget's label color
     fn text_color(&self) -> Color {
-        Color::from_hex_str(&self.inner().style(Style::Color)).unwrap()
+        Color::from_hex_str(&self.inner().style(Style::Color)).unwrap_throw()
     }
     fn set_text_size(&self, size: u8) {
         self.inner().set_style(Style::FontSize, &size.to_string());
     }
     fn text_size(&self) -> u8 {
-        self.inner().style(Style::FontSize).parse().unwrap()
+        self.inner().style(Style::FontSize).parse().unwrap_throw()
     }
     fn set_text_font(&self, font: &str) {
         self.inner().set_style(Style::Font, font);
